intelmq.bots.experts.csv_converter package — intelmq 3.0.0.alpha.1 documentation

# intelmq.bots.experts.csv_converter package

## Submodules

## intelmq.bots.experts.csv_converter.expert module

`intelmq.bots.experts.csv_converter.expert.` `BOT`

  alias of `intelmq.bots.experts.csv_converter.expert.CSVConverterExpertBot`

class `intelmq.bots.experts.csv_converter.expert.` `CSVConverterExpertBot`(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.Bot`

  Convert data to CSV

  `delimiter`: str = ','
  `fieldnames`: str = 'time.source,classification.type,source.ip'
  `init`()
  `process`()

## Module contents